\name{getExif}
\alias{getExif}

\title{Extract meta-information from digital images via libexif.}
\description{
  This function extracts information encoded in a digital image
  via EXIF (Exchangeable Image File Format).
  This version uses the C library libexif
  to read the information from the
  file(s).
  This is to be contrasted with the Python-based facility
  \code{\link{getExifPy}} also in this package.
}
\usage{
getExif(files, ..., simplify = FALSE, failOnError = TRUE,
        constructor = createExifEntry)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{files}{a character vector identifying the image files
  by fully qualified names.  ~ characters are expanded.}
\item{\dots}{additional arguments that are passed to the non-exported
  function \code{getExifElements} which are
  \code{collapse} and \code{direct}.
 }
 \item{simplify}{a logical value indicating whether to
   collapse the elements in the different groups
   into a single list (\code{TRUE}) or not (\code{FALSE}).
 }
 \item{failOnError}{a logical value that controls
   whether an error (\code{TRUE}) or a warning (\code{TRUE})
   is generated if an image file can not be read.
 }
 \item{constructor}{a function that is called with 7 arguments and returns
   an object representing the EXIF entry.
   The seven arguments are the EXIF entry nane, value, size in bytes,
   tag, format, format name, title and description.
 }
}
\details{

}
\value{
  A list with as many elements as there are in \code{files}.
  Each element is either a simple named list of elements
  if \code{simplify} is \code{TRUE} or
  alternatively a list of lists if \code{simplify} is \code{FALSE}.
}
\references{}
\author{Duncan Temple Lang <duncan@wald.ucdavis.edu>}

\seealso{
  \code{\link{getExifPy}} is a Python-based  mechanism
  for extracting the same information. It may give different
  results!
}
\note{To use this, you must have libexif installed.}
\examples{
  jpgs = list.files(system.file("images", package = "Rexif"),
                    full.names = TRUE, pattern = ".*\.JPG$")

  info = getExifPy(jpgs)
}
\keyword{interface}
\keyword{IO}
