\name{getExifDate}
\alias{getExifDate}
\title{Get the date and time information from EXIF meta-data}
\description{
  This is a function that extracts the date and time information
  and optionally converts it to a POSXIlt type in R.
  It handles the different types of EXIF representation:
  Python - with fields converted or by reference -
  and libexif.
}
\usage{
getExifDate(ex, format = "\%Y:\%m:\%d \%H:\%M:\%S", fields = c("DateTime", "DateTimeOriginal", "DateTimeDigitized"))
}

\arguments{
  \item{ex}{the single }
  \item{format}{a value passed to \code{\link[base]{strptime}} to
    interpret the date/time string.
  }
  \item{fields}{the names of the fields to look for in the EXIF data.
    If this is not specified, we append prefixes to these defaults
    for handling the Python \code{IFD_Tag} names.
  }
}

\value{
  If \code{format} is not NA, then a  \code{\link[base]{POSIXlt}} object
  created via the format value and \code{\link[base]{strptime}}.

  If \code{format} is NA, then the value of the most "specific"
  Date-Time field in the sense of earliest match in fields.
}
\references{
 
}
\author{Duncan Temple Lang <duncan@wald.ucdavis.edu>}
\note{
  This is not vectorized.
}
\seealso{
  \code{\link{getExif}}
  \code{\link{getExifPy}}  
}
\examples{
  pics = list.files(system.file("images", package = "Rexif"),
                    pattern = "\.jpg$", full.names = TRUE)

  p = getExifPy(pics[1])[[1]]
  getExifDate(p)

  p = getExifPy(pics[1], convert = FALSE)[[1]]
  getExifDate(p)

  p = getExif(pics[1])[[1]]
  getExifDate(p)
}
\keyword{IO}
