\name{getExifPy}
\alias{getExifPy}
\title{Extract the Exif data from an image file using Python}
\description{
  This function returns meta-information from a digital image
  that is stored in the Exif format
  (Exchangeable Image File Format).
  It uses a Python module written by Gene Cash to
  read the image file and extract the information in the
  header data.
  The information it returns may be different from
  that extracted via the \code{\link{getExif}}
  function in this package.
  Additionally, this method has produced errors on
  some valid image files. However, this method is
  very fast and works well for many images.
  It converts the information data into R objects
  from Python values.
}
\usage{
getExifPy(files = list.files(".", pattern = ".JPG$", full.names = TRUE), convert = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{files}{a character vector identifying the image files
  by fully qualified names.  ~ characters are expanded.}
\item{convert}{a logical value. If this is \code{TRUE},
  the resulting Python elements (\code{IFD_Tag} objects) are
  converted to their R equivalents.
  If this is \code{FALSE}, references to these objects
  are returned which can be resolved on demand.
  This approach delays the translation of data between
  Python and R  and avoids unnecessary computations
  if the caller wants only a subset of the information.
  }
}
\details{
  This uses the RSPython package and the EXIF.py file
  in this package to process the individual image files.
}
\value{
  A list with as many elements as there are files.
  Each element is 
}
\references{
  \url{http://www.omegahat.org/RSPython}
  \url{http://home.cfl.rr.com/genecash/}, Gene Cash's Python page.
}
\author{Duncan Temple Lang <duncan@wald.ucdavis.edu>}
\seealso{
  \code{\link{getExif}}
  \code{\link[RSPython]{.Python}}
}
\note{To use this, you must have RSPython installed
  and the relevant environment variables set
  via the shell scripts in the scripts/ directory of the installed RSPython
  package.}
\examples{
  jpgs = list.files(system.file("images", package = "Rexif"),
                    full.names = TRUE, pattern = ".*\.JPG$")

  info = getExifPy(jpgs)
}
\keyword{interface}
\keyword{IO}


