#include <stdio.h>
#include "jpeglib.h"

static void getDim(char *filename, int *w, int *h, int fail);
#include "RJPEG.h"


#define FOR_R

#ifdef FOR_R

#include "Rdefines.h"

SEXP
readJPEGDim(SEXP files, SEXP failOnError)
{
  int i, n, w, h;
  SEXP ans;

  n = GET_LENGTH(files);
  PROTECT(ans = allocVector(INTSXP, 2 * n));
  for(i = 0; i < n; i++) {
     getDim(CHAR(STRING_ELT(files, i)), &w, &h, LOGICAL(failOnError)[0]);
     INTEGER(ans)[i] = w;
     INTEGER(ans)[n + i] = h;
  }

  UNPROTECT(1);
  return(ans);
}
#endif /* For R*/



void
error_handler(j_common_ptr cinfo)
{
  char *buf[6000];
  R_ErrorInfo *info = (R_ErrorInfo *) cinfo->client_data;

    /*XXX Need name of file */
  if(info->fail) {
     PROBLEM "error in libjpeg for file %s", info->filename
     ERROR;
  } else {
     PROBLEM "error in libjpeg for file %s", info->filename
     WARN;
  }
}


static void
getDim(char *filename, int *w, int *h, int fail)
{
  FILE * infile;
  R_ErrorInfo errorData;

  struct jpeg_decompress_struct cinfo;
  struct jpeg_error_mgr jerr;


  cinfo.err = jpeg_std_error(&jerr);
  jerr.error_exit = error_handler; 
  jerr.output_message = error_handler; 

  errorData.fail = fail;
  errorData.filename = filename;
  cinfo.client_data = &errorData;

  jpeg_create_decompress(&cinfo);

  infile = fopen(filename, "rb");
  if(!infile)  {
      *w = *h = -1;
      return;
   }
  jpeg_stdio_src(&cinfo, infile);
  (void) jpeg_read_header(&cinfo, TRUE);
  *h = cinfo.image_height;
  *w = cinfo.image_width;
  fclose(infile);

  jpeg_destroy_compress(&cinfo);
}

SEXP
R_getComments(const char *filename)
{
  int i, n;
  FILE * infile;
  SEXP ans;
  struct jpeg_decompress_struct cinfo;
  struct jpeg_error_mgr jerr;
  struct jpeg_marker_struct *ptr;

  cinfo.err = jpeg_std_error(&jerr);
  jpeg_create_decompress(&cinfo);

  infile = fopen(filename, "rb");
  if(!infile)  {
      return(R_NilValue);
   }
  jpeg_stdio_src(&cinfo, infile);
  jpeg_save_markers(&cinfo, JPEG_COM, 0xFFFF);
  (void) jpeg_read_header(&cinfo, TRUE);

  ptr = cinfo.marker_list;
  n = 0;
  while(ptr) {
    n++;
    ptr->next;
  }

  PROTECT(ans = allocVector(STRSXP, n));
  if(n > 0) {
     i = 0;
     ptr = cinfo.marker_list;
     while(ptr) {
       SET_STRING_ELT(ans, i, mkChar(ptr->data));
       i++;
     }
  } else 
     ans = R_NilValue;

  UNPROTECT(1);

  fclose(infile);
  jpeg_destroy_compress(&cinfo);

  return(ans);
}

SEXP
R_getJPEGComments(SEXP files)
{
  int i, n;
  SEXP ans;

  n = GET_LENGTH(files);
  PROTECT(ans = allocVector(VECSXP, n));
  for(i = 0; i < n; i++) {
     SET_VECTOR_ELT(ans, i, R_getComments(CHAR(STRING_ELT(files, i))));
  }
  SET_NAMES(ans, files);
  UNPROTECT(1);
  return(ans);
}

#ifndef FOR_R
int 
main(int argc, char *argv[])
{
  int w, h;
  fprintf(stderr, "%s\n", argv[1]);
  getDim(argv[1], &w, &h), 
  fprintf(stderr, "Width = %d, Height = %d\n", w, h);

  return(0);
}
#endif
